@@ -1,4 +1,5 @@
 from datetime import date, datetime
+from decimal import Decimal
 
 from functools import partial
 
@@ -44,6 +45,11 @@ class CompareHelper(object):
         for value in x, y:
             if value is not marker:
                 args.append(value)
+        for value in 'x', 'y':
+            explicit = 'explicit_{}'.format(value)
+            if explicit in kw:
+                kw[value] = kw[explicit]
+                del kw[explicit]
         try:
             compare(*args, **kw)
         except Exception as e:
@@ -84,6 +90,10 @@ class TestCompare(CompareHelper, TestCase):
     def test_number_different(self):
         self.check_raises(1, 2, '1 != 2')
 
+    def test_decimal_different(self):
+        self.check_raises(Decimal(1), Decimal(2),
+                          "Decimal('1') != Decimal('2')")
+
     def test_different_with_labels(self):
         self.check_raises(1, 2, '1 (expected) != 2 (actual)',
                           x_label='expected', y_label='actual')
@@ -291,6 +301,30 @@ class TestCompare(CompareHelper, TestCase):
             "[4]"
             )
 
+    def test_list_different_float(self):
+        self.check_raises(
+            [1, 2, 3.0], [1, 2, 4.0],
+            "sequence not as expected:\n\n"
+            "same:\n"
+            "[1, 2]\n\n"
+            "first:\n"
+            "[3.0]\n\n"
+            "second:\n"
+            "[4.0]"
+            )
+
+    def test_list_different_decimal(self):
+        self.check_raises(
+            [1, 2, Decimal(3)], [1, 2, Decimal(4)],
+            "sequence not as expected:\n\n"
+            "same:\n"
+            "[1, 2]\n\n"
+            "first:\n"
+            "[Decimal('3')]\n\n"
+            "second:\n"
+            "[Decimal('4')]"
+            )
+
     def test_list_totally_different(self):
         self.check_raises(
             [1], [2],
@@ -1353,13 +1387,18 @@ b
                           message="'x' (expected) != 'y' (actual)")
 
     def test_explicit_both(self):
-        self.check_raises(message="'x' (expected) != 'y' (actual)",
-                          expected='x', actual='y')
+        self.check_raises(expected='x', actual='y',
+                          message="'x' (expected) != 'y' (actual)")
+
+    def test_implicit_and_labels(self):
+        self.check_raises('x', 'y',
+                          x_label='x_label', y_label='y_label',
+                          message="'x' (x_label) != 'y' (y_label)")
 
     def test_explicit_and_labels(self):
-        self.check_raises(message="'x' (x_label) != 'y' (y_label)",
-                          expected='x', actual='y',
-                          x_label='x_label', y_label='y_label')
+        self.check_raises(explicit_x='x', explicit_y='y',
+                          x_label='x_label', y_label='y_label',
+                          message="'x' (x_label) != 'y' (y_label)")
 
     def test_invalid_two_args_expected(self):
         with ShouldRaise(TypeError(
